@@ -13,8 +13,8 @@ test_that("render_rmarkdown copies image files in subdirectories", {
 })
 
 test_that("render_rmarkdown yields useful error", {
-  skip_if_not_installed("rlang", "0.99")
-  skip_if_no_pandoc()
+  skip_on_cran() # don't understand why it fails on CRAN
+
   tmp <- dir_create(file_temp())
   pkg <- list(src_path = test_path("."), dst_path = tmp, bs_version = 3)
 
